@@ -20,7 +20,7 @@ typedef Eo Efl_Net_Server_Ssl;
  */
 #define EFL_NET_SERVER_SSL_CLASS efl_net_server_ssl_class_get()
 
-EWAPI const Efl_Class *efl_net_server_ssl_class_get(void) EINA_CONST;
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_server_ssl_class_get(void) EINA_CONST;
 
 /**
  * @brief Defines the SSL context to use for this server.
@@ -35,7 +35,7 @@ EWAPI const Efl_Class *efl_net_server_ssl_class_get(void) EINA_CONST;
  *
  * @ingroup Efl_Net_Server_Ssl
  */
-EOAPI void efl_net_server_ssl_context_set(Eo *obj, Efl_Net_Ssl_Context *ssl_context);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_server_ssl_context_set(Eo *obj, Efl_Net_Ssl_Context *ssl_context);
 
 /**
  * @brief Defines the SSL context to use for this server.
@@ -51,7 +51,7 @@ EOAPI void efl_net_server_ssl_context_set(Eo *obj, Efl_Net_Ssl_Context *ssl_cont
  *
  * @ingroup Efl_Net_Server_Ssl
  */
-EOAPI Efl_Net_Ssl_Context *efl_net_server_ssl_context_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Efl_Net_Ssl_Context *efl_net_server_ssl_context_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
