@@ -16,7 +16,7 @@ typedef Eo Efl_Ui_Spotlight_Util;
 #ifdef EFL_BETA_API_SUPPORT
 #define EFL_UI_SPOTLIGHT_UTIL_CLASS efl_ui_spotlight_util_class_get()
 
-EWAPI const Efl_Class *efl_ui_spotlight_util_class_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *efl_ui_spotlight_util_class_get(void) EINA_CONST;
 
 /**
  * @brief Get a preconfigured stack obejct
@@ -25,7 +25,7 @@ EWAPI const Efl_Class *efl_ui_spotlight_util_class_get(void) EINA_CONST;
  *
  * @ingroup Efl_Ui_Spotlight_Util
  */
-EOAPI Efl_Ui_Spotlight_Container *efl_ui_spotlight_util_stack_gen(Efl_Ui_Widget *parent);
+EAPI EAPI_WEAK Efl_Ui_Spotlight_Container *efl_ui_spotlight_util_stack_gen(Efl_Ui_Widget *parent);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
